<?php
/**
 * Wise functions and definitions
 *
 * @package Wise
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'wise_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function wise_theme_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Wise, use a find and replace
	 * to change 'wise' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'wise', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'wise' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	/*
	 * Enable post thumbnail
	 */
	add_theme_support( "post-thumbnails" );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'wise_theme_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );


	/*
	 * Add editor style
	 */
	add_editor_style( 'editor-style.css' );
}
endif; // wise_theme_setup
add_action( 'after_setup_theme', 'wise_theme_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function wise_theme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'wise' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 1', 'wise' ),
		'id'            => 'sidebar-footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 2', 'wise' ),
		'id'            => 'sidebar-footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 3', 'wise' ),
		'id'            => 'sidebar-footer-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'wise_theme_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function wise_theme_scripts() {

	wp_register_style( 'VarelaRound', '//fonts.googleapis.com/css?family=Varela+Round' );
	wp_register_style( 'Lato', '//fonts.googleapis.com/css?family=Lato:400,700' );

	wp_enqueue_style( 'VarelaRound' );
	wp_enqueue_style( 'Lato' );

	wp_enqueue_style( 'wise_theme-style', get_stylesheet_uri() );

	wp_enqueue_script( 'wise_theme-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'wise_theme-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_script( 'wise_theme-backstretch', get_template_directory_uri() . '/js/backstretch.js', array( 'jquery' ), false, true );

	wp_register_script( 'wise_theme-main', get_template_directory_uri() . '/js/main.js', array( 'jquery' ), false, true );


	$wordpress_values = wise_theme_get_header_image();

	wp_localize_script( 'wise_theme-main', 'WPP', $wordpress_values );

	wp_enqueue_script( 'wise_theme-main' );
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'wise_theme_scripts' );


function wise_theme_get_header_image() {

	if( get_header_image() ) {
		$image_url_path = get_header_image();
	} else {
		$image_url_path = get_template_directory_uri() . "/img/header-img.jpeg";
	}
	

	$array = array(
		'siteurl'	=>	$image_url_path,
	);

	return $array;
}


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
